@@ -3,6 +3,7 @@ use crate::paths::token_path;
 use crate::render::ui::confirm_with_prompt;
 use crate::types::context::BergContext;
 
+use anyhow::Context;
 use clap::Parser;
 
 /// Logout. Delete currently stored authentication token
@@ -27,7 +28,7 @@ impl LogoutArgs {
 
         let token_path = token_path()?;
 
-        std::fs::remove_file(token_path)?;
+        std::fs::remove_file(token_path).context("Failed to remove token!")?;
 
         Ok(())
     }
