@@ -22,7 +22,7 @@ impl DeleteLabelArgs {
         let ctx = BergContext::new(self, general_args).await?;
 
         let OwnerRepo { repo, owner } = ctx.owner_repo()?;
-        let labels_list = spin_until_ready(ctx.client.issue_list_labels(
+        let (_, labels_list) = spin_until_ready(ctx.client.issue_list_labels(
             owner.as_str(),
             repo.as_str(),
             IssueListLabelsQuery::default(),
