@@ -1,10 +1,12 @@
 use forgejo_api::structs::User;
 
 use crate::actions::GeneralArgs;
+use crate::render::json::JsonToStdout;
 use crate::render::option::option_display;
 use crate::render::spinner::spin_until_ready;
 use crate::types::context::BergContext;
 use crate::types::git::OwnerRepo;
+use crate::types::output::OutputMode;
 
 use clap::Parser;
 
@@ -14,14 +16,18 @@ pub struct RepoAssigneesArgs {}
 
 impl RepoAssigneesArgs {
     pub async fn run(self, general_args: GeneralArgs) -> anyhow::Result<()> {
-        let _ = general_args;
         let ctx = BergContext::new(self, general_args).await?;
 
         let OwnerRepo { repo, owner } = ctx.owner_repo()?;
-        let repo_assignees =
+        let (_, repo_assignees) =
             spin_until_ready(ctx.client.repo_get_assignees(owner.as_str(), repo.as_str())).await?;
 
-        present_repo_assignees(&ctx, repo_assignees);
+        match general_args.output_mode {
+            OutputMode::Pretty => {
+                present_repo_assignees(&ctx, repo_assignees);
+            }
+            OutputMode::Json => repo_assignees.print_json()?,
+        }
 
         Ok(())
     }
@@ -33,10 +39,11 @@ fn present_repo_assignees(ctx: &BergContext<RepoAssigneesArgs>, repo_assignees:
     table
         .set_header(vec![format!(
             "Repository Assignees{}",
-            repo_assignees
-                .is_empty()
-                .then_some(" (empty)")
-                .unwrap_or_default()
+            if repo_assignees.is_empty() {
+                " (empty)"
+            } else {
+                Default::default()
+            }
         )])
         .add_rows(
             repo_assignees
