@@ -1,5 +1,5 @@
 use crate::{
-    actions::{repo::parse_owner_and_repo, GeneralArgs},
+    actions::{GeneralArgs, repo::parse_owner_and_repo},
     types::context::BergContext,
 };
 
