@@ -4,6 +4,8 @@ pub mod create;
 pub mod delete;
 pub mod fork;
 pub mod info;
+pub mod list;
+pub mod migrate;
 
 use clap::Subcommand;
 
@@ -18,6 +20,8 @@ pub enum RepoArgs {
     Fork(fork::RepoForkArgs),
     Info(info::RepoInfoArgs),
     Assignees(assignees::RepoAssigneesArgs),
+    Migrate(migrate::RepoMigrateArgs),
+    List(list::RepoListArgs),
 }
 
 impl RepoArgs {
@@ -29,6 +33,8 @@ impl RepoArgs {
             RepoArgs::Fork(args) => args.run(general_args).await,
             RepoArgs::Info(args) => args.run(general_args).await,
             RepoArgs::Assignees(args) => args.run(general_args).await,
+            RepoArgs::Migrate(args) => args.run(general_args).await,
+            RepoArgs::List(args) => args.run(general_args).await,
         }
     }
 }
