@@ -1,4 +1,4 @@
-use time::{format_description, OffsetDateTime};
+use time::{OffsetDateTime, format_description};
 
 use crate::types::config::BergConfig;
 
