@@ -1,17 +1,19 @@
 use chrono::Datelike;
-use time::{format_description, Date, OffsetDateTime, Time};
+use time::{Date, OffsetDateTime, Time, format_description};
 
 pub fn render_datetime_and_info(datetime: &OffsetDateTime) -> String {
     let days_passed = (OffsetDateTime::now_utc() - *datetime).whole_days();
     let at_least_one_day_passed = days_passed > 0;
 
-    let extra_info = at_least_one_day_passed
-        .then(|| {
+    let extra_info = if at_least_one_day_passed {
+        {
             let multiple_days_passed = days_passed > 1;
             let day_word = if multiple_days_passed { "days" } else { "day" };
             format!(" ({days_passed} {day_word} ago)")
-        })
-        .unwrap_or_default();
+        }
+    } else {
+        Default::default()
+    };
     format!(
         "{}{extra_info}",
         datetime
