@@ -10,13 +10,14 @@ pub async fn berg_main() {
             Ok(config) => config,
             Err(e) => {
                 eprintln!("{e:?}");
-                return;
+                std::process::exit(1);
             }
         };
         let mut table = config.make_table();
         table.add_row(vec![
-            comfy_table::Cell::new(format!("{e:?}")).fg(comfy_table::Color::Red)
+            comfy_table::Cell::new(format!("{e:?}")).fg(comfy_table::Color::Red),
         ]);
         eprintln!("{table}", table = table.show());
+        std::process::exit(1);
     }
 }
