@@ -1,5 +1,6 @@
 use std::ops::{Deref, DerefMut};
 
+use anyhow::Context;
 use derive_new::new;
 
 use crate::paths::token_path;
@@ -22,6 +23,8 @@ impl DerefMut for Token {
 
 impl Token {
     pub fn read_from_data_dir() -> anyhow::Result<Self> {
-        Ok(Self(std::fs::read_to_string(token_path()?)?))
+        let token_path = token_path()?;
+        let token = std::fs::read_to_string(token_path).context("Reading token failed!")?;
+        Ok(Self(token))
     }
 }
